def run_test(virtual_bond=False):
    print(f'Running test with virtual_bond = {virtual_bond}')
    #
    # Load a protein:ligand system
    #
    def deserialize(filename):
        import bz2
        open_method = bz2.open if '.bz2' in filename else open
        with open_method(filename, 'rt') as infile:
            import openmm
            return openmm.XmlSerializer.deserialize(infile.read())

    # Load System with virtual bond connecting protein-ligand and protein-protein dimer
    system = deserialize('system.xml.bz2')
    # Load State
    state = deserialize('state.xml.bz2')
    # Load reference positions for RMSD
    # In this PDB file, the protein dimer and ligand are all together
    import mdtraj
    trajectory = mdtraj.load('equilibrated-all.pdb')
    mdtop = trajectory.topology
    rmsd_reference_positions = trajectory.openmm_positions(0)

    # Get the protein and ligand indices (excluding any solvent)
    import mdtraj
    rmsd_atom_indices = mdtop.select('(protein and name CA) or ((not water) and (not resname CL) and (not resname NA) and (mass > 1.5))')

    if virtual_bond is False:
        # Remove CustomBondForce zero-energy virtual bond connecting protein-ligand and protein-protein dimer
        forces = { force.getName() : index for (index, force) in enumerate(system.getForces()) }
        system.removeForce(forces['CustomBondForce'])

    # Add the RMSD force
    from simtk import unit, openmm
    kB = unit.AVOGADRO_CONSTANT_NA * unit.BOLTZMANN_CONSTANT_kB 
    temperature = 300 * unit.kelvin
    kT = kB * temperature     
    sigma = 1.0 * unit.angstrom
    buffer = 2.0 * unit.angstrom
    custom_cv_force = openmm.CustomCVForce('step(RMSD-buffer)*(K_RMSD/2)*(RMSD-buffer)^2')
    custom_cv_force.addGlobalParameter('K_RMSD', kT / sigma**2)
    custom_cv_force.addGlobalParameter('buffer', buffer)
    rmsd_force = openmm.RMSDForce(rmsd_reference_positions, rmsd_atom_indices)
    custom_cv_force.addCollectiveVariable('RMSD', rmsd_force)
    system.addForce(custom_cv_force)

    # Add a barostat
    pressure = 1.0 * unit.atmospheres
    barostat = openmm.MonteCarloBarostat(pressure, temperature)
    system.addForce(barostat)

    # Create an integrator
    collision_rate = 1.0 / unit.picoseconds
    timestep = 2.0 * unit.femtoseconds
    integrator = openmm.LangevinMiddleIntegrator(temperature, collision_rate, timestep)

    # Create a Context
    context = openmm.Context(system, integrator)
    context.setState(state)

    # Run the simulation, reporting RMSD
    niterations = 10
    nsteps = 500
    for iteration in range(niterations):
        cvs = custom_cv_force.getCollectiveVariableValues(context)
        print(f'Time : {context.getTime() / unit.picoseconds:12.3f} ps : RMSD {cvs[0] * 10:12.3f} A')
        integrator.step(nsteps)

    del context, integrator

#
# Run the test
#

for virtual_bond in [True, False]:
    run_test(virtual_bond)
